package l_msg_api

// 业务系统和模板配置
type (
	Base struct {
		ServerIndex string `json:"server_index"` // 业务系统
		TempIndex   string `json:"temp_index"`   // 配置模板
	}

	accessTokenResponse struct {
		Code int    `json:"code"`
		Msg  string `json:"msg"`
		Data struct {
			AccessToken  string `json:"accessToken"`  // 授权token
			AccessExpire int    `json:"accessExpire"` // 过期时间
		} `json:"data"`
	}

	OACreatePurchaseResponse struct {
		Code int    `json:"code"`
		Msg  string `json:"msg"`
		Data struct {
			IsSuccess  bool   `json:"is_success"` // 是否成功 true 成功 false 失败
			Msg        string `json:"msg"`
			InstanceId string `json:"instance_id"` // 审批实例id
		} `json:"data"`
	}

	// 封装上游采购审批表单数据
	formDataRequest struct {
		Base Base `json:"base"`
		formsData
	}
	formsData struct {
		FormBase
		FormComponentValues []formComponentValues `json:"form_component_values"` // 审批表单数据
	}
	formComponentValues struct { // 审批表单数据
		Name          string `json:"name"`
		Value         string `json:"value"`
		ComponentType string `json:"component_type,omitempty"`
		ExtValue      string `json:"extValue,omitempty"`
	}

	// 创建OA基础数据
	FormBase struct {
		OutTradeNo       string `json:"out_trade_no"`       // 流水号
		OriginatorUserId string `json:"originator_user_id"` // 钉钉申请人id
	}

	// 创建采购审批表单数据
	CreatePurchaseForm struct {
		FormBase
		PurchaseNum       string // 采购单号
		SupplierName      string //供应商名称
		TotalCount        string //采购总数量
		TotalAmount       string //采购总金额
		WarehouseName     string //入库仓库
		ExpectArrivalTime string //预计到货时间

		Remark                    string //采购备注
		PurchaseType              string //采购类型
		PayType                   string //支付类型
		TotalAmountUpperCase      string //总金额大写
		SupplierSettlementBank    string //结算账户开户行
		SupplierSettlementAccount string //结算账户

		PurchaseInGoodsList []PurchaseInGoods
	}

	// 采购单商品列表
	PurchaseInGoods struct {
		GoodsCode string `json:"goods_code"` // 商品编码
		GoodsName string `json:"goods_name"` // 商品名称
		Count     string `json:"count"`      // 数量
		Price     string `json:"price"`      // 单价
		Total     string `json:"total"`      // 总价
	}

	// 获取审批实列详情 请求数据
	oAGetDetailRequest struct {
		Base              Base   `json:"base"`
		OutTradeNo        string `json:"out_trade_no"`        // 流水号
		ProcessInstanceId string `json:"process_instance_id"` // 审批实例id
	}

	// 获取审批实列详情 返回数据
	OAGetDetailData struct {
		OutTradeNo        string `json:"out_trade_no"`        // 流水号
		ProcessInstanceId string `json:"process_instance_id"` // 审批实例id
		Title             string `json:"title"`               // 审批标题
		Result            int    `json:"result"`              // 审批结果，（1：同意，2：拒绝）
		Type              string `json:"type"`                // 审批类型 '任务状态变更类型,start：审批任务开始,finish：审批任务正常结束（完成或转交）
		Remarks           string `json:"remarks"`             // 审批备注
		CreateTime        string `json:"createTime"`          // 审批创建时间
		UpdateTime        string `json:"updateTime"`          // 审批更新时间
	}
	OAGetDetailResponse struct {
		Code int             `json:"code"`
		Msg  string          `json:"msg"`
		Data OAGetDetailData `json:"data"`
	}

	// 创建客户充值审批表单数据
	CreateCustomerRechargeForm struct {
		FormBase
		Initiator            string //发起人
		CustomerName         string //客户名称
		RecipientAccountName string //收款账户名称
		RechargeType         string //充值类型
		RechargeAmount       string //充值金额
		Voucher              string //充值凭证
		Remark               string //备注
		CreatedAt            string //创建时间
	}

	// 创建供应商充值审批表单数据
	CreateSupplierRechargeForm struct {
		FormBase
		Initiator            string //发起人
		SupplierName         string //供应商名称
		RecipientAccountName string //收款账户名称
		RechargeType         string //充值类型
		RechargeAmount       string //充值金额
		Voucher              string //充值凭证
		Remark               string //备注
		CreatedAt            string //创建时间
	}

	/*
	   OaNotifyData	回调通知数据
	   Method: POST
	   {"content-type": "application/json; charset=utf-8"},
	*/
	OaNotifyData struct {
		OutTradeNo        string `json:"out_trade_no"`        // 下游流水号
		ProcessInstanceId string `json:"process_instance_id"` // 创建审批任务返回的 审批实例id
		Title             string `json:"title"`               // 实例标题
		StaffId           string `json:"staff_id"`            // 当前任务的审批人userId，操作转交动作的用户userId
		Result            int32  `json:"result"`              // 审批结果，（1：同意，2：拒绝）
		Type              string `json:"type"`                // 任务状态变更类型,start：审批任务开始,finish：审批任务正常结束（完成或转交）,comment：审批任务评论,cancel：说明当前节点有多个审批人并且是或签，其中一个人执行了审批，其他审批人会推送cancel类型事件
		Remark            string `json:"remark"`              // 操作时写的评论内容
		CreatedAt         string `json:"created_at"`          // 创建时间
		UpdatedAt         string `json:"updated_at"`          // 结束时间
	}

	SmsRequest struct {
		Base  Base   `json:"base"`
		Param string `json:"param"` // 短信模板变量对应的实际值
		Tels  string `json:"tels"`
	}

	SmsSendRes struct {
		Code int     `json:"code"`
		Msg  string  `json:"msg"`
		Data SmsSend `json:"data"`
	}
	SmsSend struct {
		SendList []SmsSendResView `json:"send_list"`
	}

	SmsSendResView struct {
		Tel       string `json:"tel"`
		IsSuccess uint32 `json:"is_success"`
	}

	DingTalkBlackBoardSendReq struct {
		Base               Base                   `json:"base"`
		BlackboardReceiver BlackboardReceiverView `json:"blackboard_receiver"` //公告接收人。
		Title              string                 `json:"title,default=公告"`    //公告标题
		Content            string                 `json:"content,default=大家好"` //公告内容
	}
	BlackboardReceiverView struct {
		DeptidList []int    `json:"deptid_list"` //接收部门ID列表，最大的列表长度为20。
		UseridList []string `json:"userid_list"` //接收部用户ID列表，最大的列表长度为20。
	}

	DefaultRes struct {
		Code int     `json:"code"`
		Msg  string  `json:"msg"`
		Data Default `json:"data"`
	}
	Default struct {
		IsSuccess bool   `json:"is_success,default=false"`
		Msg       string `json:"msg,default=ok"`
	}
)
